function [I_WI,fig1,fig2]=nortek_waveplot(IMLM) 

%make sure to load the EMEP, IMLM and wavesmon samples
%EMEP=load('emep'), IMLM=load('imlm'), spec=load('wavesmon')
%rangeE=load('EMEP_range'), rangeI=load('IMLM_range')



%what is the magnetic variation to nearest degree
magvar=-10;

%what is the frequency and dir resolution for those generated in DIWASP
freqres=0.01;
freqs=[0.01:0.01:.4];
dirres=2;
dirs=[-180:2:180];

% plot the spectrum generated through DIWASP 

scrsz = get(0,'ScreenSize');
fig1=figure('Position',[scrsz]);


subplot(2,2,2);
subplotspec(IMLM,4);
title('EMEP AST beam and radial velocities');




%calculate just the dir energy spectrum on a single graph


IMLMdir=sum(real(IMLM.S))*freqres;



%calculate just the frequency energy spectrum
IMLMfreq=sum(real(IMLM.S)')*dirres;


%Compute the coefficient for the upper and lower error bounds for the
%frequency
%spectrum assuming 95% confidence.  Added on 9/17/08
degF=2*IMLM.degF; % 2* since for the Nortek the range beam sampled at 4hz (4096) is decimated or averaged to 2hz (2048)
chiUp=chi2inv(.975,degF);
chiLow=chi2inv(.025,degF);
coeffUp=degF/chiLow;
coeffLow=degF/chiUp;

%calculate the conf limits throughout the frequency spectrum

IMLMfreqUP=IMLMfreq*coeffUp;
IMLMfreqLOW=IMLMfreq*coeffLow;

%Find the maximum for the directional spectrum so we can set up the proper
%x-axis
[maxvalue,maxindex] = max(IMLMdir);
maxdir=dirs(maxindex);
% set up the x-axis for all of the spectra depending on the max
if ((100 < maxdir) || (maxdir < -100));
    %for diwasp spectra
    index1=find(dirs < 0);
    index2=find(dirs > -1);
    dirs(index1)=dirs(index1) +360;

    %plot the directional energy spectrum
    fig2=figure('Position',[scrsz]);
    subplot(1,2,1);
    h2 = plot(dirs(index2),IMLMdir(index2),'b');
    h2a= plot(dirs(index1),IMLMdir(index1),'b');
    
else
    
    %plot the directional energy spectrum
    fig2=figure('Position',[scrsz]);
    subplot(1,2,1);
    hold on
    h2a = plot(dirs,IMLMdir,'b');
    
end

legend(h2a,'EMEP');
title('directional wave spectrum integrated over frequency');
xlabel('axis angle (degrees true)');
ylabel('m^2 / deg');

%plot the frequency energy spectrum
subplot(1,2,2);
h3=plot(freqs,IMLMfreq,'r');
hold on
h4=plot(freqs,IMLMfreqUP,'r--');
plot(freqs,IMLMfreqLOW,'r--');
legend('EMEP','EMEP 95% confidence');
title('directional wave spectrum integrated over direction');
xlabel('frequency in Hz');
ylabel('m^2 / hz');

% ______Calculate and display the wave parameters SigH, Tp, Dp,DTp_______



% For IMLM AST and radial velocities

%calculate the 0,1,2 moments
m0=sum(IMLMfreq*freqres);                              
m1=sum(freqs.*IMLMfreq*freqres);
m2=sum((freqs.^2).*IMLMfreq*freqres);
% Calculate the Sig wave height
IMLM_Hsig=4*sqrt(m0);
%Use the function HsigConf.m to calculate the sigH confidence limits
IMLM_HsConf=nortek_HsigConf(IMLM);

% Calculate the peak period Tp
[P,I]=max(IMLMfreq);
IMLM_Tp=1/(freqs(I));

%Calculate the Direction of the peak period DTp
[P,I]=max(real(IMLM.S(I,:)));
IMLM_DTp=dirs(I);

%Calculate the Dominant Direction Dp
[P,I]=max(IMLMdir);
IMLM_Dp=dirs(I);

%Display on the screen the SigH,Tp,Dp,DTp
disp(['EMEP']);
disp(['SigH (meters): ' num2str(IMLM_Hsig)]);
disp(['SigH 95% conf. (meters): ' num2str(IMLM_HsConf)]);
disp(['peak period (seconds): ' num2str(IMLM_Tp)]);
disp(['Dir of peak period: ' num2str(compangle(IMLM_DTp, IMLM.xaxisdir))]);
disp(['Dominant Direction: ' num2str(compangle(IMLM_Dp, IMLM.xaxisdir))]);
disp(['  ']);

I_WI.hsig=IMLM_Hsig;
I_WI.hconf=IMLM_HsConf;
I_WI.tp=IMLM_Tp;
I_WI.dtp=compangle(IMLM_DTp, IMLM.xaxisdir);
I_WI.dp=compangle(IMLM_Dp, IMLM.xaxisdir);




%function to change from axis angles to compass bearings

function angle=compangle(angle,xaxisdir)
angle=xaxisdir*ones(size(angle))-angle;
angle=angle+360*(angle<0);
angle=angle-360*(angle>360);





